===========================
 API Reference
===========================

:Release: |version|
:Date: |today|

.. toctree::
    :maxdepth: 2

    kombu
    kombu.common
    kombu.mixins
    kombu.simple
    kombu.clocks
    kombu.compat
    kombu.pidbox
    kombu.exceptions
    kombu.log
    kombu.connection
    kombu.message
    kombu.compression
    kombu.pools
    kombu.abstract
    kombu.syn
    kombu.async
    kombu.async.hub
    kombu.async.semaphore
    kombu.async.timer
    kombu.transport
    kombu.transport.pyamqp
    kombu.transport.librabbitmq
    kombu.transport.memory
    kombu.transport.redis
    kombu.transport.zmq
    kombu.transport.beanstalk
    kombu.transport.mongodb
    kombu.transport.couchdb
    kombu.transport.zookeeper
    kombu.transport.filesystem
    kombu.transport.django
    kombu.transport.django.models
    kombu.transport.django.managers
    kombu.transport.django.management.commands.clean_kombu_messages
    kombu.transport.sqlalchemy
    kombu.transport.sqlalchemy.models
    kombu.transport.SQS
    kombu.transport.SLMQ
    kombu.transport.pyro
    kombu.transport.amqplib
    kombu.transport.base
    kombu.transport.virtual
    kombu.transport.virtual.exchange
    kombu.transport.virtual.scheduling
    kombu.serialization
    kombu.utils
    kombu.utils.eventio
    kombu.utils.limits
    kombu.utils.compat
    kombu.utils.debug
    kombu.utils.encoding
    kombu.utils.functional
    kombu.utils.url
    kombu.utils.text
    kombu.utils.amq_manager
    kombu.five
